==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1DownwardAPIProjectionFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1DownwardAPIProjectionFluent<A extends V1DownwardAPIProjectionFluent<A>> extends Fluent<A>{


    public A addToItems(int index,V1DownwardAPIVolumeFile item);
    public A setToItems(int index,V1DownwardAPIVolumeFile item);
    public A addToItems(V1DownwardAPIVolumeFile... items);
    public A addAllToItems(Collection<V1DownwardAPIVolumeFile> items);
    public A removeFromItems(V1DownwardAPIVolumeFile... items);
    public A removeAllFromItems(Collection<V1DownwardAPIVolumeFile> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1DownwardAPIVolumeFile> getItems();
    public List<V1DownwardAPIVolumeFile> buildItems();
    public V1DownwardAPIVolumeFile buildItem(int index);
    public V1DownwardAPIVolumeFile buildFirstItem();
    public V1DownwardAPIVolumeFile buildLastItem();
    public V1DownwardAPIVolumeFile buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);
    public A withItems(List<V1DownwardAPIVolumeFile> items);
    public A withItems(V1DownwardAPIVolumeFile... items);
    public Boolean hasItems();
    public V1DownwardAPIProjectionFluent.ItemsNested<A> addNewItem();
    public V1DownwardAPIProjectionFluent.ItemsNested<A> addNewItemLike(V1DownwardAPIVolumeFile item);
    public V1DownwardAPIProjectionFluent.ItemsNested<A> setNewItemLike(int index,V1DownwardAPIVolumeFile item);
    public V1DownwardAPIProjectionFluent.ItemsNested<A> editItem(int index);
    public V1DownwardAPIProjectionFluent.ItemsNested<A> editFirstItem();
    public V1DownwardAPIProjectionFluent.ItemsNested<A> editLastItem();
    public V1DownwardAPIProjectionFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1DownwardAPIVolumeFileFluent<V1DownwardAPIProjectionFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1DownwardAPIProjectionFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1DownwardAPIProjectionFluent<A extends V1DownwardAPIProjectionFluent<A>> extends Fluent<A>{


    public A addToItems(int index,V1DownwardAPIVolumeFile item);
    public A setToItems(int index,V1DownwardAPIVolumeFile item);
    public A addToItems(V1DownwardAPIVolumeFile... items);
    public A addAllToItems(Collection<V1DownwardAPIVolumeFile> items);
    public A removeFromItems(V1DownwardAPIVolumeFile... items);
    public A removeAllFromItems(Collection<V1DownwardAPIVolumeFile> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1DownwardAPIVolumeFile> getItems();
    public List<V1DownwardAPIVolumeFile> buildItems();
    public V1DownwardAPIVolumeFile buildItem(int index);
    public V1DownwardAPIVolumeFile buildFirstItem();
    public V1DownwardAPIVolumeFile buildLastItem();
    public V1DownwardAPIVolumeFile buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);
    public A withItems(List<V1DownwardAPIVolumeFile> items);
    public A withItems(V1DownwardAPIVolumeFile... items);
    public Boolean hasItems();
    public V1DownwardAPIProjectionFluent.ItemsNested<A> addNewItem();
    public V1DownwardAPIProjectionFluent.ItemsNested<A> addNewItemLike(V1DownwardAPIVolumeFile item);
    public V1DownwardAPIProjectionFluent.ItemsNested<A> setNewItemLike(int index,V1DownwardAPIVolumeFile item);
    public V1DownwardAPIProjectionFluent.ItemsNested<A> editItem(int index);
    public V1DownwardAPIProjectionFluent.ItemsNested<A> editFirstItem();
    public V1DownwardAPIProjectionFluent.ItemsNested<A> editLastItem();
    public V1DownwardAPIProjectionFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1DownwardAPIVolumeFileBuilder> predicate);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1DownwardAPIVolumeFileFluent<V1DownwardAPIProjectionFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
